==> angelsbioprocessing_0.4.1.zip: angelsbioprocessing_0.4.1/prototypes/items/bio-processing-paste.lua <==
data:extend(
{
--PASTE
  {
    type = "item",
    name = "paste-cobalt",
    icon = "__angelsbioprocessing__/graphics/icons/paste-cobalt.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bio-processing-paste",
    order = "a[paste-cobalt]",
    stack_size = 200
  },    
  {
    type = "item",
    name = "paste-copper",
    icon = "__angelsbioprocessing__/graphics/icons/paste-copper.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bio-processing-paste",
    order = "a[paste-copper]",
    stack_size = 200
  },
  {
    type = "item",
    name = "paste-gold",
    icon = "__angelsbioprocessing__/graphics/icons/paste-gold.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bio-processing-paste",
    order = "a[paste-gold]",
    stack_size = 200
  }, 
  {
    type = "item",
    name = "paste-iron",
    icon = "__angelsbioprocessing__/graphics/icons/paste-iron.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bio-processing-paste",
    order = "a[paste-iron]",
    stack_size = 200
  }, 
  {
    type = "item",
    name = "paste-silver",
    icon = "__angelsbioprocessing__/graphics/icons/paste-silver.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bio-processing-paste",
    order = "a[paste-silver]",
    stack_size = 200
  },  
  {
    type = "item",
    name = "paste-titanium",
    icon = "__angelsbioprocessing__/graphics/icons/paste-titanium.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bio-processing-paste",
    order = "a[paste-titanium]",
    stack_size = 200
  },  
  {
    type = "item",
    name = "paste-tungsten",
    icon = "__angelsbioprocessing__/graphics/icons/paste-tungsten.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bio-processing-paste",
    order = "a[paste-tungsten]",
    stack_size = 200
  },    
  {
    type = "item",
    name = "paste-zinc",
    icon = "__angelsbioprocessing__/graphics/icons/paste-zinc.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bio-processing-paste",
    order = "a[paste-zinc]",
    stack_size = 200
  },    
}
)

==> angelsbioprocessing_0.7.20.zip: angelsbioprocessing_0.7.20/prototypes/items/bio-processing-paste.lua <==
data:extend(
{
  --PASTE
  {
    type = "item",
    name = "paste-cobalt",
    icon = "__angelsbioprocessing__/graphics/icons/paste-cobalt.png",
    icon_size = 32,
    subgroup = "bio-processing-paste",
    order = "a[paste-cobalt]",
    stack_size = 200
  },
  {
    type = "item",
    name = "paste-copper",
    icon = "__angelsbioprocessing__/graphics/icons/paste-copper.png",
    icon_size = 32,
    subgroup = "bio-processing-paste",
    order = "a[paste-copper]",
    stack_size = 200
  },
  {
    type = "item",
    name = "paste-gold",
    icon = "__angelsbioprocessing__/graphics/icons/paste-gold.png",
    icon_size = 32,
    subgroup = "bio-processing-paste",
    order = "a[paste-gold]",
    stack_size = 200
  },
  {
    type = "item",
    name = "paste-iron",
    icon = "__angelsbioprocessing__/graphics/icons/paste-iron.png",
    icon_size = 32,
    subgroup = "bio-processing-paste",
    order = "a[paste-iron]",
    stack_size = 200
  },
  {
    type = "item",
    name = "paste-silver",
    icon = "__angelsbioprocessing__/graphics/icons/paste-silver.png",
    icon_size = 32,
    subgroup = "bio-processing-paste",
    order = "a[paste-silver]",
    stack_size = 200
  },
  {
    type = "item",
    name = "paste-titanium",
    icon = "__angelsbioprocessing__/graphics/icons/paste-titanium.png",
    icon_size = 32,
    subgroup = "bio-processing-paste",
    order = "a[paste-titanium]",
    stack_size = 200
  },
  {
    type = "item",
    name = "paste-tungsten",
    icon = "__angelsbioprocessing__/graphics/icons/paste-tungsten.png",
    icon_size = 32,
    subgroup = "bio-processing-paste",
    order = "a[paste-tungsten]",
    stack_size = 200
  },
  {
    type = "item",
    name = "paste-zinc",
    icon = "__angelsbioprocessing__/graphics/icons/paste-zinc.png",
    icon_size = 32,
    subgroup = "bio-processing-paste",
    order = "a[paste-zinc]",
    stack_size = 200
  },
}
)
